@@ -29,38 +29,38 @@
 #' data.frame is its taxonomic classification. `media` is a list of media
 #' objects, where each element holds a set of metadata about the media object.
 
-occ_search <- function(taxonKey=NULL,
-                       scientificName=NULL,
-                       country=NULL,
-                       publishingCountry=NULL, 
-                       hasCoordinate=NULL, 
-                       typeStatus=NULL,
-                       recordNumber=NULL,
-                       lastInterpreted=NULL,
-                       continent=NULL,
-                       geometry=NULL,
-                       geom_big="asis",
-                       geom_size=40,
-                       geom_n=10,
-                       recordedBy=NULL,
-                       recordedByID=NULL,
-                       identifiedByID=NULL,
-                       basisOfRecord=NULL,
-                       datasetKey=NULL,
-                       eventDate=NULL,
-                       catalogNumber=NULL,
-                       year=NULL,
-                       month=NULL,
-                       decimalLatitude=NULL,
-                       decimalLongitude=NULL,
-                       elevation=NULL,
-                       depth=NULL,
-                       institutionCode=NULL,
-                       collectionCode=NULL,
-                       hasGeospatialIssue=NULL,
-                       issue=NULL,
-                       search=NULL,
-                       mediaType=NULL,
+occ_search <- function(taxonKey = NULL,
+                       scientificName = NULL,
+                       country = NULL,
+                       publishingCountry = NULL, 
+                       hasCoordinate = NULL, 
+                       typeStatus = NULL,
+                       recordNumber = NULL,
+                       lastInterpreted = NULL,
+                       continent = NULL,
+                       geometry = NULL,
+                       geom_big = "asis",
+                       geom_size = 40,
+                       geom_n = 10,
+                       recordedBy = NULL,
+                       recordedByID = NULL,
+                       identifiedByID =NULL,
+                       basisOfRecord = NULL,
+                       datasetKey = NULL,
+                       eventDate = NULL,
+                       catalogNumber = NULL,
+                       year = NULL,
+                       month = NULL,
+                       decimalLatitude = NULL,
+                       decimalLongitude = NULL,
+                       elevation = NULL,
+                       depth = NULL,
+                       institutionCode = NULL,
+                       collectionCode = NULL,
+                       hasGeospatialIssue = NULL,
+                       issue = NULL,
+                       search = NULL,
+                       mediaType = NULL,
                        subgenusKey = NULL,
                        repatriated = NULL,
                        phylumKey = NULL,
@@ -95,15 +95,71 @@ occ_search <- function(taxonKey=NULL,
                        lifeStage = NULL,
                        isInCluster = NULL,
                        distanceFromCentroidInMeters=NULL,
-                       limit=500,
-                       start=0,
+                       geoDistance = NULL,
+                       sex = NULL,
+                       dwcaExtension = NULL,
+                       gbifId = NULL,
+                       gbifRegion = NULL,
+                       projectId = NULL,
+                       programme = NULL,
+                       preparations = NULL,
+                       datasetId = NULL,
+                       datasetName = NULL,
+                       publishedByGbifRegion = NULL,
+                       island = NULL,
+                       islandGroup = NULL,
+                       taxonId = NULL,
+                       taxonConceptId = NULL,
+                       taxonomicStatus = NULL,
+                       acceptedTaxonKey = NULL,
+                       collectionKey = NULL,
+                       institutionKey = NULL,
+                       otherCatalogNumbers = NULL,
+                       georeferencedBy = NULL,
+                       installationKey = NULL,
+                       hostingOrganizationKey = NULL,
+                       crawlId = NULL,
+                       modified = NULL,
+                       higherGeography = NULL,
+                       fieldNumber = NULL,
+                       parentEventId = NULL,
+                       samplingProtocol = NULL,
+                       sampleSizeUnit = NULL,
+                       pathway = NULL,
+                       gadmLevel0Gid = NULL,
+                       gadmLevel1Gid = NULL,
+                       gadmLevel2Gid = NULL,
+                       gadmLevel3Gid = NULL,
+                       earliestEonOrLowestEonothem = NULL,
+                       latestEonOrHighestEonothem = NULL,
+                       earliestEraOrLowestErathem = NULL,
+                       latestEraOrHighestErathem = NULL,
+                       earliestPeriodOrLowestSystem = NULL,
+                       latestPeriodOrHighestSystem = NULL,
+                       earliestEpochOrLowestSeries = NULL,
+                       latestEpochOrHighestSeries = NULL,
+                       earliestAgeOrLowestStage = NULL,
+                       latestAgeOrHighestStage = NULL,
+                       lowestBiostratigraphicZone = NULL,
+                       highestBiostratigraphicZone = NULL,
+                       group = NULL,
+                       formation = NULL,
+                       member = NULL,
+                       bed = NULL,
+                       associatedSequences = NULL,
+                       isSequenced = NULL,
+                       startDayOfYear = NULL,
+                       endDayOfYear = NULL,
+                       limit = 500,
+                       start = 0,
                        fields = 'all',
-                       return=NULL,
+                       return = NULL,
                        facet = NULL,
                        facetMincount = NULL,
                        facetMultiselect = NULL,
                        skip_validate = TRUE,
-                       curlopts = list(http_version=2), ...) {
+                       curlopts = list(http_version=2), 
+                       ...) {
   
   pchk(return, "occ_search")
   geometry <- geometry_handler(geometry, geom_big, geom_size, geom_n)
@@ -130,6 +186,7 @@ occ_search <- function(taxonKey=NULL,
         occurrenceStatus = occurrenceStatus,
         q = search,
         repatriated = repatriated,
+        isSequenced = isSequenced,
         limit = check_limit(as.integer(limit)),
         isInCluster = isInCluster,
         offset = check_limit(as.integer(start))
@@ -195,7 +252,61 @@ occ_search <- function(taxonKey=NULL,
       convmany(occurrenceId),
       convmany(iucnRedListCategory),
       convmany(lifeStage),
-      convmany(distanceFromCentroidInMeters)
+      convmany(distanceFromCentroidInMeters),
+      convmany(sex),
+      convmany(dwcaExtension),
+      convmany(gbifId),
+      convmany(gbifRegion),
+      convmany(projectId),
+      convmany(programme),
+      convmany(preparations),
+      convmany(datasetId),
+      convmany(datasetName),
+      convmany(publishedByGbifRegion),
+      convmany(island),
+      convmany(islandGroup),
+      convmany(taxonId),
+      convmany(taxonConceptId),
+      convmany(taxonomicStatus),
+      convmany(acceptedTaxonKey),
+      convmany(collectionKey),
+      convmany(institutionKey),
+      convmany(otherCatalogNumbers),
+      convmany(georeferencedBy),
+      convmany(installationKey),
+      convmany(hostingOrganizationKey),
+      convmany(crawlId),
+      convmany(modified),
+      convmany(higherGeography),
+      convmany(fieldNumber),
+      convmany(parentEventId),
+      convmany(samplingProtocol),
+      convmany(sampleSizeUnit),
+      convmany(pathway),
+      convmany(gadmLevel0Gid),
+      convmany(gadmLevel1Gid),
+      convmany(gadmLevel2Gid),
+      convmany(gadmLevel3Gid),
+      convmany(earliestEonOrLowestEonothem),
+      convmany(latestEonOrHighestEonothem),
+      convmany(earliestEraOrLowestErathem),
+      convmany(latestEraOrHighestErathem),
+      convmany(earliestPeriodOrLowestSystem),
+      convmany(latestPeriodOrHighestSystem),
+      convmany(earliestEpochOrLowestSeries),
+      convmany(latestEpochOrHighestSeries),
+      convmany(earliestAgeOrLowestStage),
+      convmany(latestAgeOrHighestStage),
+      convmany(lowestBiostratigraphicZone),
+      convmany(highestBiostratigraphicZone),
+      convmany(group),
+      convmany(formation),
+      convmany(member),
+      convmany(bed),
+      convmany(associatedSequences),
+      convmany(startDayOfYear),
+      convmany(endDayOfYear),
+      convmany(geoDistance)
     )
     argscoll <<- args
     
@@ -308,8 +419,63 @@ occ_search <- function(taxonKey=NULL,
     iucnRedListCategory=iucnRedListCategory,
     lifeStage=lifeStage,
     coordinateUncertaintyInMeters=coordinateUncertaintyInMeters,
-    distanceFromCentroidInMeters=distanceFromCentroidInMeters
-  )
+    distanceFromCentroidInMeters=distanceFromCentroidInMeters,
+    sex=sex,
+    dwcaExtension=dwcaExtension,
+    gbifId=gbifId,
+    gbifRegion=gbifRegion,
+    projectId=projectId,
+    programme=programme,
+    preparations=preparations,
+    datasetId=datasetId,
+    datasetName=datasetName,
+    publishedByGbifRegion=publishedByGbifRegion,
+    island=island,
+    islandGroup=islandGroup,
+    taxonId=taxonId,
+    taxonConceptId=taxonConceptId,
+    taxonomicStatus=taxonomicStatus,
+    acceptedTaxonKey=acceptedTaxonKey,
+    collectionKey=collectionKey,
+    institutionKey=institutionKey,
+    otherCatalogNumbers=otherCatalogNumbers,
+    georeferencedBy=georeferencedBy,
+    installationKey=installationKey,
+    hostingOrganizationKey=hostingOrganizationKey,
+    crawlId=crawlId,
+    modified=modified,
+    higherGeography=higherGeography,
+    fieldNumber=fieldNumber,
+    parentEventId=parentEventId,
+    samplingProtocol=samplingProtocol,
+    sampleSizeUnit=sampleSizeUnit,
+    pathway=pathway,
+    gadmLevel0Gid=gadmLevel0Gid,
+    gadmLevel1Gid=gadmLevel1Gid,
+    gadmLevel2Gid=gadmLevel2Gid,
+    gadmLevel3Gid=gadmLevel3Gid,
+    earliestEonOrLowestEonothem=earliestEonOrLowestEonothem,
+    latestEonOrHighestEonothem=latestEonOrHighestEonothem,
+    earliestEraOrLowestErathem=earliestEraOrLowestErathem,
+    latestEraOrHighestErathem=latestEraOrHighestErathem,
+    earliestPeriodOrLowestSystem=earliestPeriodOrLowestSystem,
+    latestPeriodOrHighestSystem=latestPeriodOrHighestSystem,
+    earliestEpochOrLowestSeries=earliestEpochOrLowestSeries,
+    latestEpochOrHighestSeries=latestEpochOrHighestSeries,
+    earliestAgeOrLowestStage=earliestAgeOrLowestStage,
+    latestAgeOrHighestStage=latestAgeOrHighestStage,
+    lowestBiostratigraphicZone=lowestBiostratigraphicZone,
+    highestBiostratigraphicZone=highestBiostratigraphicZone,
+    group=group,
+    formation=formation,
+    member=member,
+    bed=bed,
+    associatedSequences=associatedSequences,
+    isSequenced=isSequenced,
+    startDayOfYear=startDayOfYear,
+    endDayOfYear=endDayOfYear,
+    geoDistance=geoDistance
+    )
   if (!any(sapply(params, length) > 0)) {
     stop(sprintf("At least one of these parameters must have a value:\n%s",
                  possparams()),
